@@ -135,6 +135,16 @@ class StandardFunction:
         data_vector_2 = param_dict["data_vector_2"]
         return np.add(data_vector_1, data_vector_2)
 
+    @staticmethod
+    def divide(param_dict):
+        '''
+        :param param_dict:
+        :return:
+        '''
+        data_vector_1 = param_dict["data_vector_1"]
+        data_vector_2 = param_dict["data_vector_2"]
+        return np.divide(data_vector_1, data_vector_2)
+
     @staticmethod
     def row_sum(param_dict):
         '''
