@@ -74,6 +74,13 @@ class BinoutData(object):
         else:
             assert False
 
+        # check if the time_diff is already constant:
+        # https://stackoverflow.com/questions/3844801/check-if-all-elements-in-a-list-are-identical
+        # https://numpy.org/doc/stable/reference/generated/numpy.allclose.html
+        time_diff = np.diff(time_)
+        if(np.allclose(time_diff, np.tile([time_diff[0]], len(time_diff)))):    
+            return time_
+
         time_interp = np.linspace(time_[0], end_time_, len(time_))
         return time_interp
 
@@ -375,7 +382,7 @@ class BinoutData(object):
 
         data_array = None
         for tpl in converted_tuples:
-            d = self.get_measurement_channel(id=ids[tpl[0]], channel_name=tpl[1])
+            d = self.get_measurement_channel(id_=ids[tpl[0]], channel_name=tpl[1])
             data_array = d if data_array is None else np.append(data_array, d, axis=1)
 
         data_offset = 0
@@ -387,7 +394,7 @@ class BinoutData(object):
 
         return data_array[data_offset:data_delta_t]
 
-    def get_measurement_channel(self, id, channel_name):
+    def get_measurement_channel(self, id_, channel_name):
         """
         returns the interpolated channel,
         Aim: Constant time interval
@@ -398,20 +405,21 @@ class BinoutData(object):
         if channel_name == 'time':
             return self._time_interp.reshape(-1, 1)
         if np.issubdtype(self._ids.dtype, np.number):
-            data_index = np.where(int(id) == self._ids)[0]
+            data_index = np.where(int(id_) == self._ids)[0]
         else:  # madymo case
-            data_index = np.where(id == self._ids)[0]
+            data_index = np.where(id_ == self._ids)[0]
 
         if len(data_index) == 0:
-            self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id) + ' not in binout')
+            self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id_) + ' not in binout')
             exit()
 
-        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id) + ' from channel name: ' + channel_name)
+        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
         assert(len(data_index) >= 1)
 
         if channel_name not in self._data.keys():
-            self._logger.emit(LOGConstants.ERROR[0], str(id) + ' has no data with the identifier : ' + channel_name)
+            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
             return []
 
         d = self._data[channel_name][:, data_index]
+
         return d.reshape(-1, len(data_index))
