@@ -108,7 +108,7 @@ class PartDisbout(BinoutData):
         data_array = None
         for tpl in converted_tuples:
             for element_id in part_ids_to_element_ids[part_ids[tpl[0]]]:
-                d = self.get_measurement_channel(id=element_id, channel_name=tpl[1])
+                d = self.get_measurement_channel(id_=element_id, channel_name=tpl[1])
                 data_array = d if data_array is None else np.append(data_array, d, axis=1)
 
         data_offset = 0
@@ -1028,7 +1028,7 @@ class Glstat(BinoutData):
 
         self._data = {**self._data, **data}
 
-    def get_measurement_channel(self, id, channel_name):
+    def get_measurement_channel(self, id_, channel_name):
         """
         returns interpolated data of the channel name from self._data
         identified by channel_name
@@ -1037,7 +1037,7 @@ class Glstat(BinoutData):
             return self._time_interp.reshape(-1, 1)
 
         if channel_name not in self._data.keys():
-            self._logger.emit(LOGConstants.ERROR[0], str(id) + ' has no data with the identifier : ' + channel_name)
+            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
             return []
         self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'ENERGY_GLOBAL read from channel name: ' + channel_name)
 
@@ -1144,7 +1144,7 @@ class RCForc(BinoutData):
         '''
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, "rcforc")
 
-    def get_measurement_channel(self, id, channel_name):
+    def get_measurement_channel(self, id_, channel_name):
         '''
 
         :param id:
@@ -1155,8 +1155,8 @@ class RCForc(BinoutData):
             return self._time.reshape(-1, 1)
 
         # split id into number and master slave indicator
-        id_nr = int(id[:-1])
-        id_slave_master = id[-1]
+        id_nr = int(id_[:-1])
+        id_slave_master = id_[-1]
 
         assert (id_slave_master == 's' or id_slave_master == 'm')
 
@@ -1168,11 +1168,11 @@ class RCForc(BinoutData):
             exit()
         data_index = [data_index[id_slave_master]]
 
-        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id) + ' from channel name: ' + channel_name)
+        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
         assert (len(data_index) >= 1)
 
         if channel_name not in self._data.keys():
-            self._logger.emit(LOGConstants.ERROR[0], str(id) + ' has no data with the identifier : ' + channel_name)
+            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
             return []
 
         d = self._data[channel_name][:, data_index]
