@@ -11,7 +11,7 @@ from ..utils.constants import PluginsParamDictDef, DataPluginConstants, Definiti
 
 class DataVisualizationController(PluginInterface, Plugin):
 
-    def __init__(self, calculation_procedure_def_file, object_def_file, data_source, user_function_object=None, code_type="BINOUT"):
+    def __init__(self, calculation_procedure_def_file, object_def_file, data_source, user_function_object=None, code_type="LS-DYNA"):
         '''
         Initialization i.e. call Plugin constructor
 
@@ -47,6 +47,9 @@ class DataVisualizationController(PluginInterface, Plugin):
 
         x_data = copy.copy(self._get_data_from_dynasaur_json(json_object=json_object[DataPluginConstants.X],
                                                              data_offsets=reduced_sample_offsets_x))
+        if x_data is None:
+            return
+
         if x_label.startswith(DataPluginConstants.TIME):
             x_data_time = self._data[reduced_sample_offsets_x[0][0]].get_interpolated_time()[
                           reduced_sample_offsets_x[0][1]:reduced_sample_offsets_x[0][2]]
@@ -55,6 +58,9 @@ class DataVisualizationController(PluginInterface, Plugin):
 
         y_data = copy.copy(self._get_data_from_dynasaur_json(json_object=json_object[DataPluginConstants.Y],
                                                              data_offsets=reduced_sample_offsets_y))
+        if y_data is None:
+            return
+
         if y_label.startswith(DataPluginConstants.TIME):
             # start_time = self._data.get_time()[[reduced_sample_offsets_x]]
             y_data_time = self._data[reduced_sample_offsets_x[0][0]].get_interpolated_time()[
@@ -195,5 +201,7 @@ class DataVisualizationController(PluginInterface, Plugin):
         find max length of data visualization list
         :return max length:
         '''
+        if len(data_dict.keys()) == 0:
+            return 0
         length = np.max([len(data_dict[p][d]["X"]) for p in data_dict.keys() for d in data_dict[p].keys()])
         return length
