@@ -8,7 +8,7 @@ from lasso.dyna.Binout import Binout
 
 from ..utils.constants import StandardFunctionsDefinition, JsonConstants, ObjectConstantsForData, LoggerERROR
 from ..calc.standard_functions import StandardFunction
-from ..utils.constants import LOGConstants, CodeType, PluginsParamDictDef
+from ..utils.constants import LOGConstants, PluginsParamDictDef
 from ..utils.logger import ConsoleLogger
 from ..data.dynasaur_definitions import DynasaurDefinitions
 from ..data.DataContainer import DataContainer
@@ -16,7 +16,7 @@ from ..data.vps import VPSData
 from ..data.madymo import MadymoData
 
 class Plugin(object):
-    def __init__(self, path_to_def_file, path_def_file_id, data_source, name, user_function_object=None, volume_path=None, code_type="BINOUT"):
+    def __init__(self, path_to_def_file, path_def_file_id, data_source, name, user_function_object=None, volume_path=None, code_type="LS-DYNA"):
         '''
         Initialization class constructor
 
@@ -36,7 +36,7 @@ class Plugin(object):
         self._user_function = user_function_object
         #self._code_type = self._dynasaur_definitions.get_code()
 
-        if code_type == "BINOUT":
+        if code_type == "LS-DYNA":
             binout = Binout(data_source)
             DataContainer.init_all_data_sources(binout, self._logger, self._dynasaur_definitions, volume_path=volume_path)
         elif code_type == "VPS":
@@ -44,11 +44,8 @@ class Plugin(object):
             DataContainer.init_all_data_sources(vps_data, self._logger, self._dynasaur_definitions, volume_path=volume_path)
 
         elif code_type == "MADYMO":
-            try:
-                madymo_data = MadymoData(madymo_file_path=data_source)
-                DataContainer.init_data_source_nodout(madymo_data, self._logger, self._dynasaur_definitions)
-            except:
-                exit("Problem occur while loading H5 file!")
+            madymo_data = MadymoData(madymo_file_path=data_source)
+            DataContainer.init_all_data_sources(madymo_data, self._logger, self._dynasaur_definitions, volume_path=volume_path)
         else:
             #TODO: Error msg
             print("Not valid code type")
